#
# postfix_main_cf_changes.rb
#

module Puppet::Parser::Functions
  newfunction(:postfix_main_cf_changes, :type => :rvalue, :doc => <<-EOS
This function takes a hash of postfix config variable / value pairs, and
returns an augeas changeset for main.cf.

*Example:*

    postfix_main_cf_changes({'inet_interfaces'=>'eth0', })

Would result in: ["set inet_interfaces 'eth0'"]
    EOS
  ) do |arguments|

    # Validate the number of arguments.
    if arguments.size != 1
      raise(Puppet::ParseError, "postfix_main_cf_changes(): Takes exactly one " +
            "argument, but #{arguments.size} given.")
    end

    # Validate the first argument.
    hash = arguments[0]
    if not hash.is_a?(Hash)
      raise(TypeError, "postfix_main_cf_changes(): The first argument must be an " +
            "hash, but a #{h.class} was given.")
    end

    # Join the keys to their values. We enclose the argument in single quotes, escaping any we find in the value.
    hash.map do |k,v|
      "set %s '%s'" % [String(k), String(v).gsub('\'','\\\'')]
    end
  end
end
