# Amavis, spamassassin, clamav

class postfix::amavis (
  $amavis_package             = $postfix::amavis_package,
  $clamav_package             = $postfix::clamav_package,
  $amavis_service             = $postfix::amavis_service,
  $amavis_options             = $postfix::amavis_options,
  $amavis_return_options      = $postfix::amavis_return_options,
  $amavis_host                = $postfix::amavis_host,
  $amavis_port                = $postfix::amavis_port,
  $amavis_return_port         = $postfix::amavis_return_port,
  $amavis_maxproc             = $postfix::amavis_maxproc,
  $filter_base_options        = $postfix::filter_base_options,
  $filter_return_base_options = $postfix::filter_return_base_options,
) inherits postfix {
  package {
    'amavis':
      ensure => present,
      name   => $amavis_package;
    'clamav':
      ensure => present,
      require => $clamav_package_require,
      name   => $clamav_package;
  } ->
  file {
    '/etc/amavisd/amavisd.conf':
      content => template('postfix/amavisd.conf.erb');
  } ~>
  service {
    'amavis':
      ensure => running,
      name   => $amavis_service,
      enable => true;
  }

  postfix::configure {
    'amavis':
      changes => {
        content_filter => "smtp-amavis:[${amavis_host}]:${amavis_port}"
      }
  }

  # Ref https://wiki.centos.org/HowTos/Amavisd
  postfix::service {
    'smtp-amavis':
      type           => 'unix',
      chroot         => 'n',
      maxproc        => $amavis_maxproc,
      command        => 'smtp',
      config_options => merge($filter_base_options,$amavis_options),
      order          => 30;
    'amavis-return':
      service        => "127.0.0.1:${amavis_return_port}",
      type           => 'inet',
      private        => 'n',
      chroot         => 'n',
      maxproc        => 100,
      command        => 'smtpd',
      config_options => merge($filter_return_base_options, $amavis_return_options),
      order          => 31;
  }
}
