# == Class: postfix::config
#
# Configuration control for the postfix class.
#

class postfix::config (
  $config_options = $postfix::config_options,
  $master_cf = $postfix::master_cf,
  $cleanup_options = $postfix::cleanup_options,
  $submission_options = $postfix::submission_options,
  $submission_base_options = $postfix::submission_base_options,
  $smtps_options = $postfix::smtps_options,
  $amavis_options = $postfix::amavis_options,
  $amavis_return_options = $postfix::amavis_return_options,
  $root_mail_alias = $postfix::root_mail_alias,
  $postmap = $postfix::postmap,
  $fqdn = $postfix::fqdn,
  $domain = $postfix::domain,
) inherits postfix {

  $config_base_options = {
    myhostname => $fqdn,
    mydomain => $domain,
    myorigin => '$mydomain'
  }

  # Customize main.cf as requested
  if $config_options {
    postfix::configure {
      'config_options':
        changes => merge($config_base_options, $config_options);
    }
  }

  # Set up master.cf, including all default services (except cleanup)
  concat::fragment {
    "${master_cf}_header":
      target  => $master_cf,
      content => template('postfix/master.cf.erb'),
      order   => 0;
  }

  # Always include the cleanup service, allowing customizations
  postfix::service {
    'cleanup':
      private        => 'n',
      chroot         => 'n',
      maxproc        => 0,
      command        => 'cleanup',
      config_options => $cleanup_options,
      order          => 10;
  }

  # enable the submission service : STARTTLS on port 567
  if ($submission_options) {
    postfix::service {
      'submission':
        type           => inet,
        private        => 'n',
        chroot         => 'n',
        command        => 'smtpd',
        config_options => merge($submission_base_options, $submission_options),
        order          => 20;
    }
  }

  # enable the smtps service : raw TLS on port 456
  if ($smtps_options) {
    postfix::service {
      'smtps':
        type           => inet,
        private        => 'n',
        chroot         => 'n',
        command        => 'smtpd',
        config_options => merge($submission_base_options, {
          syslog_name           => 'postfix/smtps',
          smtpd_tls_wrappermode => 'yes',
          }, $smtps_options),
        order          => 22;
    }
  }

  # enable the amavisd service
  if is_hash($amavis_options) or is_hash($amavis_return_options) {
    class { 'postfix::amavis': }
  }

  if ($root_mail_alias) {
    mailalias {
      'root':
        recipient => $root_mail_alias;
    } ~>
    exec {
      "${postmap} /etc/aliases":
        refreshonly => true;
    }
  }
}
