# == Class: postfix
#
# This class manages a postfix installation.
# It provides integrated support for operational Amavis/Clam and LDAP.
#
# === Parameters
#
# With no parameters, it creates a usable mail server that can deliver e-mail to local users (user@hostname).
#
# [*config_options*]
#   Key-value pairs that will be applied as configuration variables in main.cf. Default `undef`.
#
# [*submission_options*]
#   If defined, the `submission` service (port 567) is enabled in master.cf,
#   with the given options overriding a "sensible" set of base options.
#
# [*smtps_options*]
#   If defined, the `smtps` service (port 456) is enabled in master.cf,
#   with the given options overriding a "sensible" set of base options.
#
# [*root_mail_alias*]
#   The e-mail address of the user(s) who should receive root mail
#   (most service e-mail addresses, by default, are aliased to root).  If not set,
#   root mail will be delivered locally (e.g. to `/var/spool/mail/root`).
#
# === Examples
#
#  class { postfix:
#    config_options => {
#      inet_interfaces => 'all',
#      recipient_delimiter => '+',
#    }
#  }
#
# === Authors
#
# Brad2014 <brad2014@github.com>
#
# === Copyright
#
# Copyright 2016 Brad2014.
#

class postfix (
  $config_options = undef,
  $submission_options = undef,
  $smtps_options = undef,
  $cleanup_options = undef,
  $amavis_options = undef,
  $amavis_return_options = undef,
  $amavis_log_level = 0,
  $root_mail_alias = undef,
  $ldap_base_dn = undef,
  $ldap_bind_dn = undef,
  $ldap_bind_pw = undef,
  $ldap_server = 'localhost',
  $ldap_port = 389,
  $domain = $::domain,
  $fqdn = $::fqdn,
  $package = $::postfix::params::package,
  $service = $::postfix::params::service,
  $master_cf = $::postfix::params::master_cf,
) inherits postfix::params {

  package {
    'postfix':
      ensure => present,
      name   => $package;
  } ->
  concat {
    $master_cf:
      ensure => present,
      mode   => '0644',
      order  => numeric;
  } ~>
  service {
    'postfix':
      ensure => running,
      name   => $service,
      enable => true;
  }

  include config
}
