# == Class: postfix::params
#


class postfix::params {
  $package_name = 'postfix'
  $service_name = 'postfix'
  $etc_dir = '/etc/postfix'
  $postmap = '/sbin/postmap'
  $master_cf = "${etc_dir}/master.cf"

  $amavis_host = '127.0.0.1'
  $amavis_port = '10024'
  $amavis_return_port = '10025'
  $amavis_package = 'amavisd-new'
  $amavis_service = 'amavisd'
  $amavis_log_level = 0
  $amavis_maxproc = 3
  $amavis_domain = $::domain
  $amavis_filter = '(|(mail=%m)(alias=%m))'
  $amavis_spam_subject_tag = '***SPAM*** '

  $ldap_server = 'localhost'
  $ldap_port = 389
  $ldap_dir = "${etc_dir}/ldap"

  $default_config_options = {
    recipient_delimiter => '+',
    inet_interfaces => 'all'
  }

  $submission_base_options = {
    syslog_name => 'postfix/submission',
    smtpd_sasl_auth_enable => 'yes',
    smtpd_reject_unlisted_recipient => 'no',
    smtpd_recipient_restrictions => 'permit_sasl_authenticated,reject',
    milter_macro_daemon_name => 'ORIGINATING',
  }

  $filter_base_options = {
    smtp_data_done_timeout => '1800',
    disable_dns_lookups => 'yes',
    smtp_send_xforward_command => 'yes',
    max_use => '20',
    smtp_bind_address => '127.0.0.1',
  }

  $filter_return_base_options = {
    content_filter => '',
    receive_override_options => 'no_header_body_checks,no_unknown_recipient_checks,no_milters,no_address_mappings',
    local_recipient_maps => '',
    relay_recipient_maps => '',
    smtpd_restriction_classes => '',
    smtpd_client_restrictions => '',
    smtpd_helo_restrictions => '',
    smtpd_sender_restrictions => '',
    smtpd_recipient_restrictions => 'permit_mynetworks,reject',
    smtpd_tls_security_level => 'none',
    mynetworks => '127.0.0.0/8',
    smtpd_authorized_xforward_hosts => '127.0.0.0/8',
  }

  case $::osfamily {
    RedHat: {
      package { epel:
        ensure => present,
        name   => 'epel-release'
      } ->
      yumrepo { epel:
        ensure => present
      }
      $clamav_package_require = Yumrepo['epel']
      $clamav_package = 'clamav-server-systemd'
      $clamdsock = '/var/run/clamd.amavisd/clamd.sock'
    }
  }



}
