# == Defined Type: postfix::postmap
#
# This type creates and manages a map file.  Exactly one of **source** or **content** must be given.
# When changed, postfix is notified.
#
# === Parameters
#
# [**source**]
#    The source file containing the content of the map file.
#
# [**content**]
#    The content string for the map file.
#
# === Examples
#
# postfix::postmap {
#   'header_checks':
#     source => "puppet://header_checks",
# }
#
# === Authors
#
# Brad2014 <brad2014@github.com>
#
# === Copyright
#
# Copyright 2016 Brad2014.
#

define postfix::postmap (
  $source = undef,
  $content = undef,
) {
  include ::postfix::params

  $file = "${::postfix::params::etc_dir}/${name}"

  file {
    $file:
      require => Package['postfix'],
      mode    => '0644',
  } ~>
  exec {
    "${postfix::params::postmap} ${file}":
      refreshonly => true;
  }

  if ( $content ) {
    File[$file] { content => $content }
  } else {
    File[$file] { source => $source }
  }
}
