require 'spec_helper_acceptance'

describe 'postfix' do
  context 'with default configuration' do
    let(:manifest) { <<-EOS
        class { 'postfix': }
      EOS
    }

    specify 'should provision with no errors' do
      apply_manifest(manifest, :catch_failures => true)
    end

    specify 'should be idempotent' do
      apply_manifest(manifest, :catch_changes => true)
    end

    describe file('/etc/postfix/master.cf') do
      it { should be_file }
      it { should be_owned_by 'root' }
      it { should be_grouped_into 'root' }
      it { should be_mode 644 }
      its(:content) { should match /^smtp .* smtpd$/ }
    end

    describe port(25) { it { should be_listening }}
  end

  context 'with submission enabled' do
    let(:manifest) { <<-EOS
      class { 'postfix':
        fqdn => 'mailhost.example.com',
        domain => 'example.com',
        config_options => { inet_interfaces => 'all' },
        submission_options => {},
        amavis_options => {},
      }
      EOS
    }

    specify 'should provision with no errors' do
      apply_manifest(manifest, :catch_failures => true)
    end

    specify 'should be idempotent' do
      apply_manifest(manifest, :catch_changes => true)
    end

    [ 25, 587, 10025 ].each do |p|
      describe port(p) do
        it { should be_listening }
      end
    end
  end
end
